@@ -52,12 +52,19 @@ pub enum Token {
         raw: JsWord,
     },
 
-    // TODO BadUrl
+    BadUrl {
+        value: JsWord,
+        raw: JsWord,
+    },
+
     Delim {
         value: char,
     },
 
-    Num(NumToken),
+    Num {
+        value: f64,
+        raw: JsWord,
+    },
 
     // TODO Percentage
 
@@ -98,8 +105,3 @@ pub enum Token {
     /// `}`
     RBrace,
 }
-
-#[derive(Debug, Clone, PartialEq, Serialize, Deserialize)]
-pub struct NumToken {
-    pub value: f64,
-}
